@@ -3,17 +3,18 @@
 This module provides functions to create mock geff graphs for testing and development.
 It includes both simple convenience functions and a comprehensive function for advanced use cases.
 
+
 Examples:
     # Simple 2D graph with defaults
-    >>> store, props = create_simple_2d_geff()
+    >>> store, memory_geff = create_simple_2d_geff()
     >>> # Creates: 10 nodes, 15 edges, undirected, 2D (x, y, t)
 
     # Simple 3D graph with custom size
-    >>> store, props = create_simple_3d_geff(num_nodes=20, num_edges=30)
+    >>> store, memory_geff = create_simple_3d_geff(num_nodes=20, num_edges=30)
     >>> # Creates: 20 nodes, 30 edges, undirected, 3D (x, y, z, t)
 
     # Advanced usage with full control
-    >>> store, props = create_memory_mock_geff(
+    >>> store, memory_geff = create_mock_geff(
     ...     node_id_dtype="int",
     ...     node_axis_dtypes={"position": "float64", "time": "float32"},
     ...     directed=True,
@@ -33,7 +34,7 @@ Examples:
     >>> custom_labels = np.array(["A", "B", "C", "D", "E"])
     >>> custom_scores = np.array([0.1, 0.5, 0.8, 0.3, 0.9])
     >>> custom_edge_weights = np.array([0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8])
-    >>> store, props = create_memory_mock_geff(
+    >>> store, memory_geff = create_mock_geff(
     ...     node_id_dtype="int",
     ...     node_axis_dtypes={"position": "float64", "time": "float64"},
     ...     directed=False,
@@ -48,42 +49,41 @@ Examples:
     ...     include_x=True,
     ... )
 
-    # Using with GeffReader
-    >>> from geff import GeffReader
-    >>> store, props = create_simple_2d_geff()
-    >>> reader = GeffReader(store)
-    >>> graph = reader.read_nx()
+    # To construct an graph with a backend graph lib
+    >>> # Import construct function of your choice
+    >>> store, memory_geff = create_simple_2d_geff()
+    >>> graph = construct_nx(**memory_geff)
     >>> # graph is a networkx Graph ready for analysis
 """
 
-from typing import Any, Literal, TypedDict, cast, get_args
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any, Literal, TypedDict, get_args
 
-import networkx as nx
 import numpy as np
 import zarr
 import zarr.storage
-from numpy.typing import NDArray
 
-import geff
+from geff.core_io import write_arrays
+from geff_spec import Axis, PropMetadata
+from geff_spec.utils import (
+    add_or_update_props_metadata,
+    create_or_update_metadata,
+    create_props_metadata,
+)
+
+if TYPE_CHECKING:
+    from collections.abc import Mapping
+
+    from numpy.typing import NDArray
+
+    from geff._typing import InMemoryGeff, PropDictNpArray
+    from geff_spec._valid_values import AxisType, SpaceUnits, TimeUnits
+
 
 DTypeStr = Literal["double", "int", "int8", "uint8", "int16", "uint16", "float32", "float64", "str"]
-NodeIdDTypeStr = Literal["int", "int8", "uint8", "int16", "uint16"]
-Axes = Literal["t", "z", "y", "x"]
-
-
-class GraphAttrs(TypedDict):
-    nodes: NDArray[Any]
-    edges: NDArray[Any]
-    t: NDArray[Any]
-    z: NDArray[Any]
-    y: NDArray[Any]
-    x: NDArray[Any]
-    extra_node_props: dict[str, NDArray[Any]]
-    extra_edge_props: dict[str, NDArray[Any]]
-    directed: bool
-    axis_names: tuple[Axes, ...]
-    axis_units: tuple[str, ...]
-    axis_types: tuple[str, ...]
+NodeIdDTypeStr = Literal["uint", "uint8", "uint16", "uint32", "uint64"]
+AxesOptions = Literal["t", "z", "y", "x"]
 
 
 class ExampleNodeAxisPropsDtypes(TypedDict):
@@ -91,19 +91,21 @@ class ExampleNodeAxisPropsDtypes(TypedDict):
     time: DTypeStr
 
 
-def create_dummy_graph_props(
+def create_dummy_in_mem_geff(
     node_id_dtype: NodeIdDTypeStr,
     node_axis_dtypes: ExampleNodeAxisPropsDtypes,
     directed: bool,
     num_nodes: int = 5,
     num_edges: int = 4,
-    extra_node_props: dict[str, DTypeStr | NDArray[Any]] | None = None,
-    extra_edge_props: dict[str, DTypeStr | NDArray[Any]] | None = None,
+    extra_node_props: Mapping[str, DTypeStr | NDArray[Any]] | None = None,
+    extra_edge_props: Mapping[str, DTypeStr | NDArray[Any]] | None = None,
     include_t: bool = True,
     include_z: bool = True,
     include_y: bool = True,
     include_x: bool = True,
-) -> GraphAttrs:
+    include_varlength: bool = False,
+    include_missing: bool = False,
+) -> InMemoryGeff:
     """Create dummy graph properties for testing.
 
     Args:
@@ -118,62 +120,71 @@ def create_dummy_graph_props(
         include_z: Whether to include z dimension
         include_y: Whether to include y dimension
         include_x: Whether to include x dimension
+        include_varlength: Whether to include a variable length property. If true, will
+            make a property on nodes called "var_length" that has 2d np arrays of various
+            shapes
+        include_missing: If true, creades a node and edge prop called "sparse_prop" where every
+            other node/edge has a missing value
 
     Returns:
-        Dictionary containing all graph properties
+        InMemoryGeff containing all graph properties
     """
-    # Build axis_names, axis_units, and axis_types based on which dimensions to include
-    axis_names_list = []
-    axis_units_list = []
-    axis_types_list = []
-    if include_t:
-        axis_names_list.append("t")
-        axis_units_list.append("second")
-        axis_types_list.append("time")
-    if include_z:
-        axis_names_list.append("z")
-        axis_units_list.append("nanometer")
-        axis_types_list.append("space")
-    if include_y:
-        axis_names_list.append("y")
-        axis_units_list.append("nanometer")
-        axis_types_list.append("space")
-    if include_x:
-        axis_names_list.append("x")
-        axis_units_list.append("nanometer")
-        axis_types_list.append("space")
-
-    axis_names = cast("tuple[Axes, ...]", tuple(axis_names_list))
-    axis_units = tuple(axis_units_list)
-    axis_types = tuple(axis_types_list)
-
     # Generate nodes with flexible count
     nodes = np.arange(num_nodes, dtype=node_id_dtype)
+    node_props: dict[str, PropDictNpArray] = {}
+    node_prop_meta: list[PropMetadata] = []
 
     # Generate spatiotemporal coordinates with flexible dimensions
-    t = (
-        np.array(
-            [(i * 5 // num_nodes) + 1 for i in range(num_nodes)],
-            dtype=node_axis_dtypes["time"],
+    def _add_axis(
+        name: str,
+        ax_type: Literal[AxisType],
+        unit: str | Literal[SpaceUnits] | Literal[TimeUnits],
+        values: np.ndarray,
+    ) -> PropMetadata:
+        node_props[name] = {"values": values, "missing": None}
+        if num_nodes > 0:
+            roimin, roimax = values.min(), values.max()
+        else:
+            roimin, roimax = None, None
+        axes.append(Axis(name=name, type=ax_type, unit=unit, min=roimin, max=roimax))
+        return create_props_metadata(identifier=name, prop_data=node_props[name], unit=unit)
+
+    axes: list[Axis] = []
+    if include_t:
+        meta = _add_axis(
+            name="t",
+            ax_type="time",
+            unit="second",
+            values=np.array(
+                [(i * 5 // num_nodes) + 1 for i in range(num_nodes)],
+                dtype=node_axis_dtypes["time"],
+            ),
         )
-        if include_t
-        else np.array([], dtype="float64")  # Default dtype when time not included
-    )
-    z = (
-        np.linspace(0.5, 0.1, num_nodes, dtype=node_axis_dtypes["position"])
-        if include_z
-        else np.array([], dtype="float64")  # Default dtype when position not included
-    )
-    y = (
-        np.linspace(100.0, 500.0, num_nodes, dtype=node_axis_dtypes["position"])
-        if include_y
-        else np.array([], dtype="float64")  # Default dtype when position not included
-    )
-    x = (
-        np.linspace(1.0, 0.1, num_nodes, dtype=node_axis_dtypes["position"])
-        if include_x
-        else np.array([], dtype="float64")  # Default dtype when position not included
-    )
+        node_prop_meta.append(meta)
+    if include_z:
+        meta = _add_axis(
+            name="z",
+            ax_type="space",
+            unit="nanometer",
+            values=np.linspace(0.5, 0.1, num_nodes, dtype=node_axis_dtypes["position"]),
+        )
+        node_prop_meta.append(meta)
+    if include_y:
+        meta = _add_axis(
+            name="y",
+            ax_type="space",
+            unit="nanometer",
+            values=np.linspace(100.0, 500.0, num_nodes, dtype=node_axis_dtypes["position"]),
+        )
+        node_prop_meta.append(meta)
+    if include_x:
+        meta = _add_axis(
+            name="x",
+            ax_type="space",
+            unit="nanometer",
+            values=np.linspace(1.0, 0.1, num_nodes, dtype=node_axis_dtypes["position"]),
+        )
+        node_prop_meta.append(meta)
 
     # Generate edges with flexible count (ensure we don't exceed possible edges)
     max_possible_edges = (
@@ -182,7 +193,7 @@ def create_dummy_graph_props(
     actual_num_edges = min(num_edges, max_possible_edges)
 
     # Create edges ensuring we don't create duplicates
-    edges: list[list[Any]] = []
+    edges_: list[list[Any]] = []
     edge_count = 0
 
     # For undirected graphs, we need to be more careful about duplicates
@@ -191,7 +202,7 @@ def create_dummy_graph_props(
         for i in range(min(actual_num_edges, num_nodes - 1)):
             source_idx = i
             target_idx = i + 1
-            edges.append([int(source_idx), int(target_idx)])
+            edges_.append([int(source_idx), int(target_idx)])
             edge_count += 1
 
         # Add remaining edges as cross connections
@@ -200,11 +211,11 @@ def create_dummy_graph_props(
             source_idx = i % (num_nodes - 2)
             target_idx = (i + 2) % (num_nodes - 1) + 1
             if source_idx != target_idx:
-                edges.append([int(source_idx), int(target_idx)])
+                edges_.append([int(source_idx), int(target_idx)])
                 edge_count += 1
     else:
         # For directed graphs, we can create more edges efficiently
-        edges = []
+        edges_ = []
         edge_count = 0
         created_edges = set()  # Track created edges to avoid duplicates
 
@@ -214,7 +225,7 @@ def create_dummy_graph_props(
             target_idx = i + 1
             edge_tuple = (int(source_idx), int(target_idx))
             if edge_tuple not in created_edges:
-                edges.append([int(source_idx), int(target_idx)])
+                edges_.append([int(source_idx), int(target_idx)])
                 created_edges.add(edge_tuple)
                 edge_count += 1
 
@@ -228,7 +239,7 @@ def create_dummy_graph_props(
                 if source_idx != target_idx:
                     edge_tuple = (int(source_idx), int(target_idx))
                     if edge_tuple not in created_edges:
-                        edges.append([int(source_idx), int(target_idx)])
+                        edges_.append([int(source_idx), int(target_idx)])
                         created_edges.add(edge_tuple)
                         edge_count += 1
 
@@ -244,7 +255,7 @@ def create_dummy_graph_props(
                     if source_idx != target_idx:
                         edge_tuple = (int(source_idx), int(target_idx))
                         if edge_tuple not in created_edges:
-                            edges.append([int(source_idx), int(target_idx)])
+                            edges_.append([int(source_idx), int(target_idx)])
                             created_edges.add(edge_tuple)
                             edge_count += 1
 
@@ -252,9 +263,11 @@ def create_dummy_graph_props(
                             if edge_count >= actual_num_edges:
                                 break
 
-    edges = np.array(edges, dtype=object if node_id_dtype == "str" else node_id_dtype)
+    edges = np.array(edges_, dtype=node_id_dtype)
+    if edges.shape[0] == 0:
+        edges = edges.reshape((0, 2))
+
     # Generate extra node properties
-    extra_node_props_dict = {}
     if extra_node_props is not None:
         # Validate input is a dict
         if not isinstance(extra_node_props, dict):
@@ -280,28 +293,27 @@ def create_dummy_graph_props(
 
                 # Generate different patterns for different property types
                 if prop_dtype == "str":
-                    extra_node_props_dict[prop_name] = np.array(
+                    values = np.array(
                         [f"{prop_name}_{i}" for i in range(num_nodes)], dtype=prop_dtype
                     )
                 elif prop_dtype in ["int", "int8", "uint8", "int16", "uint16"]:
-                    extra_node_props_dict[prop_name] = np.arange(num_nodes, dtype=prop_dtype)
+                    values = np.arange(num_nodes, dtype=prop_dtype)
                 else:  # float types
-                    extra_node_props_dict[prop_name] = np.linspace(
-                        0.1, 1.0, num_nodes, dtype=prop_dtype
-                    )
+                    values = np.linspace(0.1, 1.0, num_nodes, dtype=prop_dtype)
+                prop_dict: PropDictNpArray = {"values": values, "missing": None}
+                node_props[prop_name] = prop_dict
+                node_prop_meta.append(create_props_metadata(prop_name, prop_dict))
 
             elif isinstance(prop_value, np.ndarray):
                 # Use provided array directly
-                custom_array = prop_value
-
                 # Validate array length matches num_nodes
-                if len(custom_array) != num_nodes:
+                if len(prop_value) != num_nodes:
                     raise ValueError(
-                        f"extra_node_props[{prop_name}] array length {len(custom_array)} "
+                        f"extra_node_props[{prop_name}] array length {len(prop_value)} "
                         f"does not match num_nodes {num_nodes}"
                     )
 
-                extra_node_props_dict[prop_name] = custom_array
+                node_props[prop_name] = {"values": prop_value, "missing": None}
 
             else:
                 raise ValueError(
@@ -310,8 +322,8 @@ def create_dummy_graph_props(
                 )
 
     # Generate edge properties
-    edge_props_dict = {}
-
+    edge_props_dict: dict[str, PropDictNpArray] = {}
+    edge_prop_meta: list[PropMetadata] = []
     # Generate edge properties from extra_edge_props
     if extra_edge_props is not None:
         # Validate input is a dict
@@ -338,26 +350,25 @@ def create_dummy_graph_props(
 
                 # Generate different patterns for different property types
                 if prop_dtype == "str":
-                    edge_props_dict[prop_name] = np.array(
+                    values = np.array(
                         [f"{prop_name}_{i}" for i in range(len(edges))], dtype=prop_dtype
                     )
                 elif prop_dtype in ["int", "int8", "uint8", "int16", "uint16"]:
-                    edge_props_dict[prop_name] = np.arange(len(edges), dtype=prop_dtype)
+                    values = np.arange(len(edges), dtype=prop_dtype)
                 else:  # float types
-                    edge_props_dict[prop_name] = np.linspace(0.1, 1.0, len(edges), dtype=prop_dtype)
+                    values = np.linspace(0.1, 1.0, len(edges), dtype=prop_dtype)
 
+                edge_props_dict[prop_name] = {"values": values, "missing": None}
             elif isinstance(prop_value, np.ndarray):
                 # Use provided array directly
-                custom_array = prop_value
-
                 # Validate array length matches num_edges
-                if len(custom_array) != len(edges):
+                if len(prop_value) != len(edges):
                     raise ValueError(
-                        f"extra_edge_props[{prop_name}] array length {len(custom_array)} "
+                        f"extra_edge_props[{prop_name}] array length {len(prop_value)} "
                         f"does not match number of edges {len(edges)}"
                     )
 
-                edge_props_dict[prop_name] = custom_array
+                edge_props_dict[prop_name] = {"values": prop_value, "missing": None}
 
             else:
                 raise ValueError(
@@ -365,36 +376,72 @@ def create_dummy_graph_props(
                     f"got {type(prop_value)}"
                 )
 
+            edge_prop_meta.append(
+                create_props_metadata(identifier=prop_name, prop_data=edge_props_dict[prop_name])
+            )
+
+    if include_varlength:
+        prop_name = "var_length"
+        ndim = 3
+        _dtype = np.uint64
+        values_list = []
+        for node in range(num_nodes):
+            shape = [
+                node,
+            ] * ndim
+            arr = np.ones(shape=shape, dtype=_dtype) * node
+            values_list.append(arr)
+
+        values = np.array(values_list, dtype=np.object_)
+        missing = np.zeros(shape=(num_nodes,), dtype=np.bool_)
+        if num_nodes > 0:
+            missing[0] = 1
+        prop_dict = {"values": values, "missing": missing}
+        node_props[prop_name] = prop_dict
+        node_prop_meta.append(create_props_metadata(prop_name, prop_dict))
+
+    if include_missing:
+        prop_name = "sparse_prop"
+        values = np.arange(num_nodes, dtype="float64")
+        missing = np.zeros(num_nodes, dtype=np.bool_)
+        if num_nodes > 0:
+            missing[::2] = 1
+        prop_dict = {"values": values, "missing": missing}
+        prop_meta = create_props_metadata(prop_name, prop_dict)
+        node_props[prop_name] = prop_dict
+        node_prop_meta.append(prop_meta)
+        edge_props_dict[prop_name] = prop_dict
+        edge_prop_meta.append(prop_meta)
+
+    metadata = create_or_update_metadata(metadata=None, is_directed=directed, axes=axes)
+    metadata = add_or_update_props_metadata(metadata, node_prop_meta, "node")
+    metadata = add_or_update_props_metadata(metadata, edge_prop_meta, "edge")
+
     return {
-        "nodes": nodes,
-        "edges": edges,
-        "t": t,
-        "z": z,
-        "y": y,
-        "x": x,
-        "extra_node_props": extra_node_props_dict,
-        "extra_edge_props": edge_props_dict,
-        "directed": directed,
-        "axis_names": axis_names,
-        "axis_units": axis_units,
-        "axis_types": axis_types,
+        "metadata": metadata,
+        "node_ids": nodes,
+        "edge_ids": edges,
+        "node_props": node_props,
+        "edge_props": edge_props_dict,
     }
 
 
-def create_memory_mock_geff(
+def create_mock_geff(
     node_id_dtype: NodeIdDTypeStr,
     node_axis_dtypes: ExampleNodeAxisPropsDtypes,
     directed: bool,
     num_nodes: int = 5,
     num_edges: int = 4,
-    extra_node_props: dict[str, DTypeStr | NDArray[Any]] | None = None,
-    extra_edge_props: dict[str, DTypeStr | NDArray[Any]] | None = None,
+    extra_node_props: Mapping[str, DTypeStr | NDArray[Any]] | None = None,
+    extra_edge_props: Mapping[str, DTypeStr | NDArray[Any]] | None = None,
     include_t: bool = True,
     include_z: bool = True,
     include_y: bool = True,
     include_x: bool = True,
-) -> tuple[zarr.storage.MemoryStore, GraphAttrs]:
-    """Create a mock geff graph in memory and return the zarr store and graph properties.
+    include_varlength: bool = False,
+    include_missing: bool = False,
+) -> tuple[zarr.storage.MemoryStore, InMemoryGeff]:
+    """Create a mock geff in memory and return the zarr store and the in memory geff.
 
     Args:
         node_id_dtype: Data type for node IDs
@@ -408,11 +455,16 @@ def create_memory_mock_geff(
         include_z: Whether to include z dimension
         include_y: Whether to include y dimension
         include_x: Whether to include x dimension
+        include_varlength: Whether to include a variable length property. If true, will
+            make a property on nodes called "var_length" that has 2d np arrays of various
+            shapes
+        include_missing: If true, creades a node prop called "sparse_prop" where every other
+            node has a missing value
 
     Returns:
-        Tuple of (zarr store in memory, graph properties dictionary)
+        Tuple of (zarr store in memory, InMemoryGeff)
     """
-    graph_props = create_dummy_graph_props(
+    memory_geff = create_dummy_in_mem_geff(
         node_id_dtype=node_id_dtype,
         node_axis_dtypes=node_axis_dtypes,
         directed=directed,
@@ -424,54 +476,21 @@ def create_memory_mock_geff(
         include_z=include_z,
         include_y=include_y,
         include_x=include_x,
+        include_varlength=include_varlength,
     )
 
-    # write graph with networkx api
-    graph = nx.DiGraph() if directed else nx.Graph()
-
-    for idx, node in enumerate(graph_props["nodes"]):
-        props = {
-            name: prop_array[idx] for name, prop_array in graph_props["extra_node_props"].items()
-        }
-        node_attrs = {}
-
-        # Only add spatial dimensions that are included
-        if include_t and len(graph_props["t"]) > 0:
-            node_attrs["t"] = graph_props["t"][idx]
-        if include_z and len(graph_props["z"]) > 0:
-            node_attrs["z"] = graph_props["z"][idx]
-        if include_y and len(graph_props["y"]) > 0:
-            node_attrs["y"] = graph_props["y"][idx]
-        if include_x and len(graph_props["x"]) > 0:
-            node_attrs["x"] = graph_props["x"][idx]
-
-        graph.add_node(node, **node_attrs, **props)
-
-    for idx, edge in enumerate(graph_props["edges"]):
-        props = {
-            name: prop_array[idx] for name, prop_array in graph_props["extra_edge_props"].items()
-        }
-        graph.add_edge(*edge.tolist(), **props)
-
     # Create memory store and write graph to it
     store = zarr.storage.MemoryStore()
+    write_arrays(store, **memory_geff)
 
-    geff.write_nx(
-        graph,
-        store,
-        axis_names=list(graph_props["axis_names"]),
-        axis_units=list(graph_props["axis_units"]),
-        axis_types=list(graph_props["axis_types"]),
-    )
-
-    return store, graph_props
+    return store, memory_geff
 
 
 def create_simple_2d_geff(
     num_nodes: int = 10,
     num_edges: int = 15,
     directed: bool = False,
-) -> tuple[zarr.storage.MemoryStore, GraphAttrs]:
+) -> tuple[zarr.storage.MemoryStore, InMemoryGeff]:
     """Create a simple 2D geff graph with default settings.
 
     This is a convenience function for creating basic 2D graphs without having to
@@ -483,29 +502,10 @@ def create_simple_2d_geff(
         directed: Whether the graph is directed (default: False)
 
     Returns:
-        Tuple of (zarr store in memory, graph properties dictionary)
-
-    Examples:
-        Basic usage with defaults:
-            >>> store, props = create_simple_2d_geff()
-            >>> # store is a zarr.MemoryStore with 10 nodes, 15 edges
-
-        Custom graph size:
-            >>> store, props = create_simple_2d_geff(num_nodes=5, num_edges=8)
-            >>> # store has 5 nodes, 8 edges
-
-        Directed graph:
-            >>> store, props = create_simple_2d_geff(directed=True)
-            >>> # Creates a directed graph
-
-        Using with GeffReader:
-            >>> store, props = create_simple_2d_geff()
-            >>> reader = GeffReader(store)
-            >>> graph = reader.read_nx()
-            >>> # graph is a networkx Graph with 2D spatial data (x, y, t)
+        Tuple of (zarr store in memory, InMemoryGeff)
     """
-    return create_memory_mock_geff(
-        node_id_dtype="int",
+    return create_mock_geff(
+        node_id_dtype="uint",
         node_axis_dtypes={"position": "float64", "time": "float64"},
         directed=directed,
         num_nodes=num_nodes,
@@ -522,7 +522,7 @@ def create_simple_3d_geff(
     num_nodes: int = 10,
     num_edges: int = 15,
     directed: bool = False,
-) -> tuple[zarr.storage.MemoryStore, GraphAttrs]:
+) -> tuple[zarr.storage.MemoryStore, InMemoryGeff]:
     """Create a simple 3D geff graph with default settings.
 
     This is a convenience function for creating basic 3D graphs without having to
@@ -534,37 +534,10 @@ def create_simple_3d_geff(
         directed: Whether the graph is directed (default: False)
 
     Returns:
-        Tuple of (zarr store in memory, graph properties dictionary)
-
-    Examples:
-        Basic usage with defaults:
-            >>> store, props = create_simple_3d_geff()
-            >>> # store is a zarr.MemoryStore with 10 nodes, 15 edges
-
-        Custom graph size:
-            >>> store, props = create_simple_3d_geff(num_nodes=5, num_edges=8)
-            >>> # store has 5 nodes, 8 edges
-
-        Directed graph:
-            >>> store, props = create_simple_3d_geff(directed=True)
-            >>> # Creates a directed graph
-
-        Using with GeffReader:
-            >>> store, props = create_simple_3d_geff()
-            >>> reader = GeffReader(store)
-            >>> graph = reader.read_nx()
-            >>> # graph is a networkx Graph with 3D spatial data (x, y, z, t)
-
-        Accessing spatial coordinates:
-            >>> store, props = create_simple_3d_geff()
-            >>> reader = GeffReader(store)
-            >>> graph = reader.read_nx()
-            >>> # Each node has x, y, z, t coordinates
-            >>> node_data = graph.nodes[0]
-            >>> x, y, z, t = node_data['x'], node_data['y'], node_data['z'], node_data['t']
+        Tuple of (zarr store in memory, InMemoryGeff)
     """
-    return create_memory_mock_geff(
-        node_id_dtype="int",
+    return create_mock_geff(
+        node_id_dtype="uint",
         node_axis_dtypes={"position": "float64", "time": "float64"},
         directed=directed,
         num_nodes=num_nodes,
@@ -581,7 +554,7 @@ def create_simple_temporal_geff(
     num_nodes: int = 10,
     num_edges: int = 15,
     directed: bool = False,
-) -> tuple[zarr.storage.MemoryStore, GraphAttrs]:
+) -> tuple[zarr.storage.MemoryStore, InMemoryGeff]:
     """Create a simple geff graph with only time dimension (no spatial dimensions).
 
     This function creates a graph with nodes, edges, and time coordinates,
@@ -593,26 +566,10 @@ def create_simple_temporal_geff(
         directed: Whether the graph is directed (default: False)
 
     Returns:
-        Tuple of (zarr store in memory, graph properties dictionary)
-
-    Examples:
-        Basic usage with defaults:
-            >>> store, props = create_simple_temporal_geff()
-            >>> # store is a zarr.MemoryStore with 10 nodes, 15 edges, time only
-
-        Custom graph size:
-            >>> store, props = create_simple_temporal_geff(num_nodes=5, num_edges=8)
-            >>> # store has 5 nodes, 8 edges, time only
-
-        Using with GeffReader:
-            >>> store, props = create_simple_temporal_geff()
-            >>> reader = GeffReader(store)
-            >>> graph = reader.read_nx()
-            >>> # graph is a networkx Graph with only time data
-            >>> # Each node has only 't' coordinate, no x, y, z
+        Tuple of (zarr store in memory, InMemoryGeff)
     """
-    return create_memory_mock_geff(
-        node_id_dtype="int",
+    return create_mock_geff(
+        node_id_dtype="uint",
         node_axis_dtypes={"position": "float64", "time": "float64"},
         directed=directed,
         num_nodes=num_nodes,
@@ -623,3 +580,25 @@ def create_simple_temporal_geff(
         include_y=False,  # No spatial dimensions
         include_x=False,  # No spatial dimensions
     )
+
+
+def create_empty_geff(directed: bool = False) -> tuple[zarr.storage.MemoryStore, InMemoryGeff]:
+    """Creates a geff without any nodes or edges
+
+    Args:
+        directed (bool, optional): Whether to create a directed graph. Defaults to False.
+
+    Returns:
+        tuple[zarr.storage.MemoryStore, InMemoryGeff]
+    """
+    return create_mock_geff(
+        node_id_dtype="uint",
+        node_axis_dtypes={"position": "float64", "time": "float64"},
+        directed=directed,
+        num_nodes=0,
+        num_edges=0,
+        include_t=False,  # No time
+        include_z=False,  # No spatial dimensions
+        include_y=False,  # No spatial dimensions
+        include_x=False,  # No spatial dimensions
+    )
